RankBasedEvaluator
==================

.. currentmodule:: pykeen.evaluation

.. autoclass:: RankBasedEvaluator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RankBasedEvaluator.finalize
      ~RankBasedEvaluator.process_head_scores_
      ~RankBasedEvaluator.process_tail_scores_

   .. rubric:: Methods Documentation

   .. automethod:: finalize
   .. automethod:: process_head_scores_
   .. automethod:: process_tail_scores_
